function [Py_temp, P] = addone_well_log_pruned(parameters, X, Y, Py, P, start)
% Input: Updated versions of X and Y; Original versions of Py and P.
% Output: Updated versions of Py and P.

% NOTE: Only the first row of Py is sent in since it is used only to
% calculate the P matrix when k = 1.  

[N, m] =size(X);             % N = total # data points (N), m = # regressors
d_min = parameters(1);
k_0 = parameters(2); 
v_0 = parameters(3); sig_0 = parameters(4);
k_max = parameters(5);
num_samp = parameters(6);
beta0= zeros(m,1);          % Mean of multivariate normal prior on regression coefficients

Py_temp = zeros(N,1) -Inf;
I=eye(m);               % mxm identity matrix


%***************** Calculate the Probabilities (3a) **********************
for i=start:N-d_min+1
        %Calculate beta_hat
        XTy=X(i:N,:)'*Y(i:N); 
        J=k_0*I+X(i:N,:)'*X(i:N,:); %J=inv(J);
        beta_hat=J\(k_0*beta0+XTy);
        
        %Calculate v_n and s_n
        a=N-i+1;    % 'a' is the number of data points.... not the distance between them, 
                    % which becomes relevant if data points are not equally spaced
        v_n=v_0+a;  % a is the number of data points in the segment, see above for definition
        
        s_n = v_0*sig_0 + k_0*(beta0-beta_hat)'*(beta0-beta_hat) + (Y(i:N,:)-X(i:N,:)*beta_hat)'*(Y(i:N,:)-X(i:N,:)*beta_hat);
        
        % Calculate the Probability Density of the Data - stored in log form 
        Py_temp(i) = v_0*log(sig_0*v_0/2)/2 + gammaln(v_n/2) +m*log(k_0)/2  ...
            - log(gamma(v_0/2)) - v_n*log(s_n/2)/2 - a*log(2*pi)/2 - log(det(J))/2 ;    %Minus because J is no longer inverted!
end

%*********** Update the Partition Function (3b) ********************
P_temp=zeros(k_max,1)-Inf;        % -Inf b/c starts in log form

%k is the number of change points
k=1;            % First row is different from the rest, as you add together two homogeneous segments

    temp=zeros(1,N-1);
    for v=1:N-1
        temp(v)= Py(v)+Py_temp(v+1);     % Changepoints occur at start of new segment, not at end of old one
    end
    M_temp = max(temp);
    if (M_temp>-Inf)
        temp = temp - M_temp;
        P_temp(k)=log(sum(exp(temp))) +M_temp;             % Equation (1) - Marginalize over all possible placements of the change point.
    else
        P_temp(k) = -Inf;
    end

for k=2:k_max
    temp=zeros(1,N-1);
    for v=1:N-1         
        temp(v) = P(k-1,v)+Py_temp(v+1);
    end
    M_temp = max(temp);
    if (max(temp)>-Inf)
        temp = temp - M_temp;
        P_temp(k)=log(sum(exp(temp))) + M_temp;     % Equation (4) - Marginalize over all possible placements of the change point.
    else
        P_temp(k) = -Inf;
    end
end

P = [P P_temp];

end