function cutoff = check_chgpt(Py, P, M)
% This function applies the pruning procedure described in Section 4 of the
% manuscript

N = length(Py);             % N = total # data points (N), m = # regressors

threshold = 10^-2;      % A threshold for when probabilities become negligible.
                        % The smaller the threshold, the closer to exact the algorithm becomes.

%******** (5a) Sample a Number of Change Points ***********************
    num_chgpts = M;         % We run this code after detecting the Mth change point
    %pick_k1(k)-1;          % Since we allow for 0 changepoints, function returns the index of the 'k' vector, 
                            % which is offset from the number of change points by 1 
    if(num_chgpts>1)
        
        %******** (3c)[ii] Sample the Location of the Change Points ***********
        back=N;
        kk = num_chgpts;            % Find location of the first change point, only make temp vector once
        
        temp=zeros(1,back-1);
        for v=1:back-1
            temp(v)= P(kk-1,v)+Py(v+1,back);  % Build the vector to sample from
        end
        M_temp = max(temp); temp = temp - M_temp;   % Avoids underflow
        total=log(sum(exp(temp)));
        temp(:)=exp(temp(:)-total);  % Normalize the vector
        
        alternate = find(temp>threshold);   
                % Identifies all potential change point locations whose 
                % probability exceeds the threshold value. This is for the 
                % most recently identified change point only.
        
        % The second most recent changepoint - our cutoff value
        %******** (3c)[ii] Sample the Location of the Change Points ***********
        kk=num_chgpts -1;
        
        if (kk ==1)
            
            alternate2 = zeros(1,length(alternate));
            for i = 1:length(alternate)
                % Build the probability vector for each potential position
                % of the most recent change point
                temp=zeros(1,alternate(i)-1);
                for v=1:alternate(i)-1
                    temp(v)= Py(1,v)+Py(v+1,alternate(i)); %Build the vector to sample from
                end
                M_temp = max(temp); temp = temp - M_temp;   % Avoids underflow
                total=log(sum(exp(temp)));
                temp(:)=exp(temp(:)-total); % Normalize the vector
                
                alternate2(i) = find(temp>threshold,1);
                % Identifies the EARLIEST possible position of the SECOND
                % change point for the given position of the most recently 
                % identified change point 
            end
        
        else
            
            alternate2 = zeros(1,length(alternate));
            for i = 1:length(alternate)
                
                temp=zeros(1,alternate(i)-1);
                for v=1:alternate(i)-1
                    temp(v)= P(kk-1,v)+Py(v+1,alternate(i)); %Build the vector to sample from
                end
                M_temp = max(temp); temp = temp - M_temp;   % Avoids underflow
                total=log(sum(exp(temp)));
                temp(:)=exp(temp(:)-total); % Normalize the vector
                
                
                alternate2(i) = find(temp>threshold,1);
                % Identifies the EARLIEST possible position of the SECOND
                % change point for the given position of the most recently 
                % identified change point 
            end
            
        end
        cutoff = min(alternate2);
        
    else        % We only have one change point identified, so no use looking for the position of the second change point
        cutoff = 1;     % default value
    end


end